@@ -1,14 +1,15 @@
 ## File Name: IRT.expectedCounts_sirt.R
-## File Version: 0.04
+## File Version: 0.05
 
 
 ###########################################################
 # object of class xxirt
-IRT.expectedCounts.xxirt <- function( object, ... ){
+IRT.expectedCounts.xxirt <- function( object, ... )
+{
     ll <- object$n.ik
     attr(ll,"theta") <- object$Theta
     attr(ll,"prob.theta") <- object$probs_Theta
     attr(ll,"G") <- object$G
     return(ll)
-        }
+}
 ###########################################################
