@@ -1,31 +1,34 @@
 ## File Name: IRT.modelfit.sirt.R
-## File Version: 0.17
+## File Version: 0.18
 
 
 ###########################################################
 # general model fit function for sirt objects
-IRT.modelfit.sirt <- function( object, mod ){
+IRT.modelfit.sirt <- function( object, mod )
+{
     res <- modelfit.sirt(object)
     res$IRT.IC <- CDM::IRT.IC(object)
     res$objname <- mod
     class(res) <- paste0("IRT.modelfit.", class(object) )
     return(res)
-        }
+}
 ###########################################################
 # summary IRT.modelfit.xxx
-summary.IRT.modelfit.sirt <- function( object, ... ){
+summary.IRT.modelfit.sirt <- function( object, ... )
+{
     class(object) <- "modelfit.sirt"
     summary(object)
-            }
+}
 ###########################################################
 
 ###########################################################
 # IRT.modelfit for objects of class rasch.mml
-IRT.modelfit.rasch.mml <- function( object, ... ){
+IRT.modelfit.rasch.mml <- function( object, ... )
+{
     cl <- paste(match.call())[2]
     res <- IRT.modelfit.sirt( object, mod=cl )
     return(res)
-                        }
+}
 summary.IRT.modelfit.rasch.mml <- summary.IRT.modelfit.sirt
 ###########################################################
 # IRT.modelfit smirt
@@ -44,15 +47,17 @@ summary.IRT.modelfit.gom <- summary.IRT.modelfit.sirt
 
 ###########################################################
 # summary IRT.modelfit2
-summary.IRT.modelfit.sirt2 <- function( object, ... ){
+summary.IRT.modelfit.sirt2 <- function( object, ... )
+{
     class(object) <- "tam.modelfit"
     summary(object)
-            }
+}
 ###########################################################
 
 ###########################################################
 # modelfit rm.facets
-IRT.modelfit.rm.facets <- function(object, ... ){
+IRT.modelfit.rm.facets <- function(object, ... )
+{
     mod <- paste(match.call())[2]
     data <- object$procdata$dat2.NA
     probs <- object$probs
@@ -63,7 +68,7 @@ IRT.modelfit.rm.facets <- function(object, ... ){
     res$objname <- mod
     class(res) <- paste0("IRT.modelfit.", class(object) )
     return(res)
-        }
+}
 summary.IRT.modelfit.rm.facets <- summary.IRT.modelfit.sirt2
 ############################################################
 # model fit rm.sdt
@@ -75,7 +80,8 @@ summary.IRT.modelfit.rm.sdt <- summary.IRT.modelfit.sirt2
 
 ###########################################################
 # modelfit xxirt
-IRT.modelfit.xxirt <- function(object, ... ){
+IRT.modelfit.xxirt <- function(object, ... )
+{
     mod <- paste(match.call())[2]
     data <- as.matrix( object$dat )
     probs <- object$probs_items
@@ -86,6 +92,6 @@ IRT.modelfit.xxirt <- function(object, ... ){
     res$objname <- mod
     class(res) <- paste0("IRT.modelfit.", class(object) )
     return(res)
-        }
+}
 summary.IRT.modelfit.xxirt <- summary.IRT.modelfit.sirt2
 ############################################################
