@@ -1,9 +1,10 @@
 ## File Name: fit.adisop.R
-## File Version: 2.18
+## File Version: 2.22
 ###################################################################
 # Fit ADISOP model
 fit.adisop <- function( freq.correct, wgt, conv=.0001,
-        maxit=100, epsilon=.01, progress=TRUE, calc.ll=TRUE ){
+        maxit=100, epsilon=.01, progress=TRUE, calc.ll=TRUE )
+{
     #########################
     eps2 <- epsilon
     M1 <- as.matrix( freq.correct )
@@ -24,7 +25,6 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
                         )
     dfr0$studPitem.p <- dfr0$stud.p + dfr0$item.p
     dfr0 <- dfr0[ order( dfr0$p0), ]
-#    dfr0$psort.index <- seq(1, nrow(dfr0)) #  / nrow(dfr0)
     dfr0$psort.index <- rank( dfr0$p0 )
     # define matrix I
     I.matrix <- 0*M1
@@ -34,18 +34,17 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
     Y <- Y0 <- I.matrix
     iter <- 0
     deviation <- 1000
-    if (progress){ cat("\n*******ADISOP Model*********\n") }
+    if (progress){
+        cat("\n*******ADISOP Model*********\n")
+    }
     #########################
     # begin algorithm
     while( ( iter < maxit) & ( deviation > conv ) ){
-        #****
-        # algorithm
+        #*** start algorithm
         Y0 <- Y
         # row and column averages
-#        X1 <- rowSums(Y0*wgt2) / rowSums( wgt2 )
         X1 <- rowMeans(Y0)
         X1 <- X1 - X1[1]
-#        X2 <- colSums(Y0*wgt2) / colSums( wgt2 )
         X2 <- colMeans(Y0)
         X2 <- X2 - X2[1]
         # calculate sum
@@ -57,11 +56,9 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
                     "item.X"=rep( X2, each=RR ),
                     "wgt2"=matrix( as.matrix( wgt2 ), RR*CC, 1 ),
                     "Y"=matrix( as.matrix( Y), RR*CC, 1 ),
-                    "I"=matrix( as.matrix( I.matrix), RR*CC, 1 )
-                            )
+                    "I"=matrix( as.matrix( I.matrix), RR*CC, 1 ) )
             # Y=X1 + X2
         dfr0 <- dfr0[ order( dfr0$I), ]
-#        dfr0$yf <- monoreg( x=dfr0$Y, w=dfr0$wgt2 )$yf
         dfr0$yf <- monoreg.rowwise( matrix( dfr0$Y, nrow=1 ), matrix(dfr0$wgt2,nrow=1) )[1,]
         Y <- 0*M1
         Y[ as.matrix(dfr0[, c("stud.index", "item.index" ) ] ) ] <- dfr0$yf
@@ -70,13 +67,13 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
         deviation <- max( abs( Y - Y0 ))
         iter <- iter + 1
         if (progress){
-                cat( "Iteration", iter, "- Deviation=",  round( deviation, 6 ), "\n")
-                utils::flush.console()
-                    }
-                }  # end algorithm
-    #########################
-    #*****
-    # calculate link function
+            cat( "Iteration", iter, "- Deviation=",  round( deviation, 6 ), "\n")
+            utils::flush.console()
+        }
+    }
+    #-------------- end algorithm
+
+    #**** calculate link function
     dfr0 <- data.frame( "stud.index"=rep(1:RR, CC),
                 "item.index"=rep(1:CC,each=RR),
                 "stud.p"=rep( X1,CC),
@@ -88,7 +85,6 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
     dfr0$X1PX2 <- dfr0$stud.p + dfr0$item.p
     dfr0 <- dfr0[ order( dfr0$X1PX2), ]
     dfr0$yf <- monoreg.rowwise( matrix( dfr0$p0, nrow=1 ), matrix(dfr0$wgt2,nrow=1) )[1,]
-#    dfr0$yf <- monoreg( x=dfr0$p0, w=dfr0$wgt2 )$yf
     dfr0 <- dfr0[ order( dfr0$stud.index * 1000 + dfr0$item.index ), ]
 
     Y <- 0*M1
@@ -106,16 +102,15 @@ fit.adisop <- function( freq.correct, wgt, conv=.0001,
     ll <- NULL
     if (calc.ll){
         ll <- list(
-            "ll.ind"=.calc.ll.isop( freq.correct, wgt, irtfitted=freq.correct )
-                        )
+            "ll.ind"=.calc.ll.isop( freq.correct, wgt, irtfitted=freq.correct ) )
         ll$ll.adisop <- .calc.ll.isop( freq.correct, wgt, irtfitted=G )
         NW <- mean( colSums(wgt) )
         ll$llcase.ind <- ll$ll.ind/NW
         ll$llcase.adisop <- ll$ll.adisop/NW
             }
     # output
-    res <- list( "fX"=G, "ResX"=M1 - G, "fit"=fit, "item.sc"=X2,
-                "person.sc"=X1, "ll"=ll, "freq.fitted"=dfr0)
+    res <- list( fX=G, ResX=M1 - G, fit=fit, item.sc=X2,
+                person.sc=X1, ll=ll, freq.fitted=dfr0)
     return(res)
     }
 ############################################################################
