@@ -1,10 +1,11 @@
 ## File Name: mcmc.2pnoh.R
-## File Version: 1.10
+## File Version: 1.11
 ##############################################
 # MCMC estimation 2PNO model
 mcmc.2pnoh <- function(dat, itemgroups, prob.mastery=c(.5, .8 ),
         weights=NULL, burnin=500, iter=1000, N.sampvalues=1000,
-        progress.iter=50, prior.variance=c(1,1), save.theta=FALSE ){
+        progress.iter=50, prior.variance=c(1,1), save.theta=FALSE )
+{
     s1 <- Sys.time()
     # data preparation
     dat0 <- dat
