@@ -1,278 +1,260 @@
 ## File Name: rasch.jml.R
-## File Version: 3.25
+## File Version: 3.298
 
 
-
-#-------------------------------------------------------------------------------------------------------------#
-rasch.jml <- function( dat, method="MLE", b.init=NULL,  constraints=NULL,  weights=NULL,
-                        glob.conv=10^(-6), conv1=0.00001, conv2=0.001, progress=TRUE,
-                        bsteps=4, thetasteps=2, wle.adj=0,
-                        jmliter=100, prox=TRUE, proxiter=30, proxconv=0.01,
-                        dp=NULL    , theta.init=NULL    , calc.fit=TRUE){
-    #-------------------------------------------------------------------#
-    # INPUT:                                                            #
-    # dat       ... data frame                                          #
-    # method    ... estimation method for ability parameter estimation  #
-    # b.init    ... initial values for item parameters                  #
-    # constraints ... input of constraints?
-    # weights   ... vector of survey weights                            #
-    # glob.conv ... global convergence criterion for deviance change    #
-    # conv1     ... convergence criterion for item difficulties         #
-    # conv2     ... convergence criterion for person abilities          #
-    # method    ... estimation method (WLE or MLE)                      #
-    # progress  ... should the convergence process being displayed?     #
-    # jmliter   ... maximal number of JML iterations                    #
-    # prox      ... should PROX be used? only if method=MLE           #
-    # proxiter  ... maximum number of PROX iterations                   #
-    # proxconv  ... convergence criterion for PROX estimation           #
-    # dp        ... output from data processing                         #
-    #-------------------------------------------------------------------#
- a0 <- Sys.time()
+rasch.jml <- function( dat, method="MLE", b.init=NULL, constraints=NULL, weights=NULL,
+                    center="persons", glob.conv=10^(-6), conv1=0.00001, conv2=0.001, progress=TRUE,
+                    bsteps=4, thetasteps=2, wle.adj=0, jmliter=100, prox=TRUE, proxiter=30, proxconv=0.01,
+                    dp=NULL, theta.init=NULL, calc.fit=TRUE)
+{
+    CALL <- match.call()
+    s1 <- Sys.time()
     # warning messages
-    if ( max( dat, na.rm=T )  > 1){ stop( "You should only have dichotomous data") }
+    if ( max( dat, na.rm=TRUE )  > 1){
+        stop( "You should only have dichotomous data")
+    }
+    # zz0 <- Sys.time()
 
     # display
     if ( progress ){
-        cat("---------------------------------------------------------------------------------------------------------- \n")
+        cat("-----------------------------------------------------------------\n")
         cat("Joint Maximum Likelihood Estimation \n")
         cat("Rasch Model \n")
-        cat("---------------------------------------------------------------------------------------------------------- \n")
-      }
-    #------------
+        cat("-----------------------------------------------------------------\n")
+    }
+    #--- centering of parameters
+    centeritems <- FALSE
+    centerpersons <- FALSE
+    if (center=="persons"){
         centerpersons <- TRUE
-        if (!is.null( constraints) ){ prox <- F ;  centerpersons <- F    }
+    }
+    if (center=="items"){
+        centeritems <- TRUE
+    }
+    if (! is.null(constraints) ){
+        prox <- FALSE
+        centerpersons <- FALSE
+        center <- "none"
+    }
 
-        # data preparations
-        if ( is.null(dp) ){
-                dp <- .data.prep( dat, weights=weights
-                        , use.freqpatt=FALSE
-                            )
-                    }
+    # data preparations
+    if ( is.null(dp) ){
+        dp <- .data.prep( dat, weights=weights, use.freqpatt=FALSE )
+    }
+    dat1 <- dp$dat1
+    dat2 <- dp$dat2
+    dat2.resp <- dp$dat2.resp
+    freq.patt <- dp$freq.patt
+    I <- dp$I
+    N <- n <- dp$n
 
-        dat1 <- dp$dat1
-        dat2 <- dp$dat2
-        dat2.resp <- dp$dat2.resp
-        freq.patt <- dp$freq.patt
-        I <- dp$I
-        n <- dp$n
-        # exclude extreme item response pattern (if method==MLE)
-        if ( method=="MLE" ){
-            ind <- which( ! dat1$mean %in% c(0,1) )
-            dat1 <- dat1[ ind,]
-            dat2 <- dat2[ ind,]
-            dat2.resp <- dat2.resp[ ind,]
-            }
-        #*****************
-        # work on speed improvement
-        # exist some missings?
-        some.missings <- 1 * ( mean( rowMeans( dat2.resp )    ) < 1 )
-        # compute missing response pattern
-        dat1$mp <- paste("MP", paste(rep(1,I), collapse=""), sep="")
-        dat1$mp.index <- 1
-        if ( some.missings ){
+    # exclude extreme item response pattern (if method==MLE)
+    if ( method=="MLE" ){
+        ind <- which( ! dat1$mean %in% c(0,1) )
+        dat1 <- dat1[ ind,]
+        dat2 <- dat2[ ind,]
+        dat2.resp <- dat2.resp[ ind,]
+        N <- nrow(dat1)
+    }
+
+    #**** exist some missings?
+    some.missings <- 1 * ( mean( rowMeans( dat2.resp) ) < 1 )
+    # compute missing response pattern
+    dat1$mp <- paste("MP", paste(rep(1,I), collapse=""), sep="")
+    dat1$mp.index <- 1
+    if ( some.missings ){
         dat1$mp.index <- resp.pattern2( dat2.resp )$mp.index
-                            }
-         dat1$sumscore <- rowSums( dat2 * dat2.resp )
-         ti <- paste( dat1$mp.index, "-", dat1$sumscore, sep="")
-         dat1$theta.index <- match( ti, unique( ti ))
-         dat1$caseid <- seq( 1, nrow(dat1) )
+    }
+    dat1$sumscore <- rowSums( dat2 * dat2.resp )
+    ti <- paste( dat1$mp.index, "-", dat1$sumscore, sep="")
+    dat1$theta.index <- match( ti, unique( ti ))
+    dat1$caseid <- seq( 1, nrow(dat1) )
 
-         theta.pattern <- as.data.frame(
-                stats::aggregate( dat1$caseid, list( dat1$theta.index ), min ))
-         colnames(theta.pattern) <- c("theta.index", "caseid")
+    theta.pattern <- as.data.frame( stats::aggregate( dat1$caseid, list(dat1$theta.index), min ))
+    colnames(theta.pattern) <- c("theta.index", "caseid")
 
+    theta.pattern[,"Freq"] <- rowsum( dat1$Freq, dat1$theta.index )[,1]
+    TPsapp <- 1:nrow(theta.pattern)
+    freq.thetapattern <- rowsum( dat1$Freq, dat1$theta.index )[,1]
+    if ( some.missings ){
+        freq.dat.resp.thetapattern <- rowsum( dat1$Freq  * dat2.resp, dat1$theta.index )
+    } else {
+        freq.dat.resp.thetapattern <- matrix( freq.thetapattern, nrow=length(freq.thetapattern), ncol=I ) }
 
-         theta.pattern[,"Freq"] <- rowsum( dat1$Freq, dat1$theta.index )[,1]
-         TPsapp <- 1:nrow(theta.pattern)
-        freq.thetapattern <- rowsum( dat1$Freq, dat1$theta.index )[,1]
-         if ( some.missings ){
-              freq.dat.resp.thetapattern <- rowsum( dat1$Freq  * dat2.resp, dat1$theta.index )
-                        } else {
-                freq.dat.resp.thetapattern <- matrix( freq.thetapattern,
-                                nrow=length(freq.thetapattern), ncol=I ) }
-         #*********************
-       # sufficient statistic
-       suffB <- colSums(  - dat1[,2] * dat2.resp * dat2 )
-       d2d2r <- dat2 * dat2.resp
-       d2d2m <- ( 1 - dat2 ) * dat2.resp
+    #** compute sufficient statistic
+    suffB <- colSums(  - dat1[,2] * dat2.resp * dat2 )
+    d2d2r <- dat2 * dat2.resp
+    d2d2m <- ( 1 - dat2 ) * dat2.resp
 
-       # starting values item parameter
-       if ( is.null( b.init) ){
-               b <- - stats::qlogis( colSums( dat2 * dat2.resp * dat1[,2] ) / colSums( dat1[,2] * dat2.resp ) )
-                    } else { b <- b.init }
-       if (!is.null(constraints)){ b[ constraints[,1] ] <- constraints[,2] }
+    # starting values item parameter
+    if ( is.null(b.init) ){
+        b <- - stats::qlogis( colSums( dat2 * dat2.resp * dat1[,2] ) / colSums( dat1[,2] * dat2.resp ) )
+    } else {
+        b <- b.init
+    }
+    if (!is.null(constraints)){
+        b[ constraints[,1] ] <- constraints[,2]
+    }
 
-       # starting values person paramters
-       if ( is.null(theta.init)){
-                theta <- stats::qlogis( dat1$mean * ( 1  - 1 / I ) + 1 / ( 2*I ) )
-                            } else {
-                            theta <- theta.init
-                            theta[ theta==Inf ] <- 20
-                            theta[ theta==-Inf ] <- -20
-                                }
+    # starting values person paramters
+    if ( is.null(theta.init)){
+        theta <- stats::qlogis( dat1$mean * ( 1  - 1 / I ) + 1 / ( 2*I ) )
+    } else {
+        theta <- theta.init
+        theta[ theta==Inf ] <- 20
+        theta[ theta==-Inf ] <- -20
+    }
 
-       # PROX estimation
-        if (prox  ){
-            if (method=="WLE" ){ ind <- which( ! dat1$mean %in% c(0,1) )    } else
-                                { ind <- 1:( nrow(dat1 )) }
-                prox.res <- rasch.prox( dat=dat2[ind,], dat.resp=dat2.resp[ind,], freq=dat1[ind,2],
+    #--- PROX estimation
+    if (prox){
+        if (method=="WLE" ){
+            ind <- which( ! dat1$mean %in% c(0,1) )
+        } else {
+            ind <- 1:( nrow(dat1 ))
+        }
+        prox.res <- rasch.prox( dat=dat2[ind,], dat.resp=dat2.resp[ind,], freq=dat1[ind,2],
                         conv=proxconv, progress=progress, maxiter=proxiter )
-                b <- prox.res$b
-                theta[ind] <- prox.res$theta
-                        }
-        # center across persons
-        if (centerpersons ){  theta <- theta - stats::weighted.mean( theta, dat1[,2] )     }
+        b <- prox.res$b
+        theta[ind] <- prox.res$theta
+    }
+    # centering
+    theta <- rasch_jml_centerpersons(theta=theta, dat1=dat1, centerpersons=centerpersons)
+    b <- rasch_jml_centeritems(b=b, centeritems=centeritems)
 
-        # initial settings
-        dev0 <- 1 ; dev.change <- 1 ;   iter <- 0 ;   b0 <- 0
-        bconv <- 10^10
-        disp <- "...............................\n"
+    # initial settings
+    dev0 <- 1
+    dev.change <- 1
+    iter <- 0
+    b0 <- 0
+    bconv <- 10^10
+    disp <- "...............................\n"
 
-     # JML Iteration Algorithm
-        while ( ( ( dev.change > glob.conv ) & ( iter < jmliter ) ) | ( bconv > conv1 ) ){
-            b0 <- b
-            # update item difficulties
-    if ( progress ){
+    #------------------------------------------------------
+    # JML Iteration Algorithm
+    while ( ( ( dev.change > glob.conv ) & ( iter < jmliter ) ) | ( bconv > conv1 ) ){
+        b0 <- b
+        # update item difficulties
+        if ( progress ){
             cat(disp)
             cat("JML Iteration", iter +1, "\n")
             cat("  Item parameters |")
-                }
-        b <- .update.b.rasch.jml2( b0, theta=theta[theta.pattern$caseid],
+        }
+        b <- rasch_jml_update_b( b0, theta=theta[theta.pattern$caseid],
                         freq.thetapattern=freq.thetapattern,
-                        freq.dat.resp.thetapattern=freq.dat.resp.thetapattern    ,
+                        freq.dat.resp.thetapattern=freq.dat.resp.thetapattern,
                         constraints=constraints, conv=conv2,
                         suffB=suffB, progress=progress, bsteps=bsteps)
-            # ability estimate (method==MLE or method==WLE)
-            ind <- theta.pattern$caseid
-            if (method=="WLE" ){
-                    m1 <- wle.rasch( dat=dat2[ind,], b=b,
-                                theta=theta[ ind ],
-                                dat.resp=dat2.resp[ ind, ],  conv=conv2,
-                                progress=progress, maxit=thetasteps,
-                            wle.adj=wle.adj        )
-                                        }
-            if (method=="MLE" ){
-                    m1 <- mle.rasch( dat=dat2[ind,], b=b, theta=theta[ind],
-                            dat.resp=dat2.resp[ind,],  conv=conv2,
+        b <- rasch_jml_centeritems(b=b, centeritems=centeritems)
+        # ability estimate (method==MLE or method==WLE)
+        ind <- theta.pattern$caseid
+        if (method=="WLE" ){
+            m1 <- wle.rasch( dat=dat2[ind,], b=b, theta=theta[ ind ],
+                        dat.resp=dat2.resp[ ind, ], conv=conv2, progress=progress, maxit=thetasteps,
+                        wle.adj=wle.adj )
+        }
+        if (method=="MLE" ){
+            m1 <- mle.rasch( dat=dat2[ind,], b=b, theta=theta[ind], dat.resp=dat2.resp[ind,],  conv=conv2,
                             progress=progress )
-                                    }
-            theta <- m1$theta
-            theta <- theta[ dat1$theta.index ]
-            # center theta around the mean
-            if (centerpersons){
-                    theta <- theta - stats::weighted.mean( theta, dat1[,2] )
-                        }
-            # calculate Log-Likelihood and Deviance
-             p.ia <- (m1$p.ia)[ dat1$theta.index, ]
-             dev1 <- -2*sum( rowSums( ( d2d2r * log( p.ia ) + d2d2m * log( 1 - p.ia ) ) ) * dat1[,2]  )
-            # relative deviance change
-            dev1a <- - (dev1 - dev0)
-            dev.change <- abs( dev1 - dev0 ) / dev0 ;
-            dev0 <- dev1
-            # iteration index
-            iter <- iter + 1
-            # display convergence
-            bconv <- max( abs(b - b0 ) )
-        if ( progress ){
-                cat( paste( "\n  Deviance=", round( dev1, 5 ) ))
-                if (iter > 1){ cat(    " | Deviance change=", round( dev1a, 5 ) ) }
-                                cat( "\n  Max. parm. change=",
-                                 round( bconv, 6 ), "\n"  )
-                                  utils::flush.console()
-                                  }
-                            }
-
-        # display
-        if ( progress ){
-          if ( iter < jmliter ){  cat( paste( "Convergence reached in", iter, "JML Iterations \n" ) )      }
-                else {       cat( paste( "Analysis terminated at", iter, "JML Iterations \n" ) )      }
-          cat("---------------------------------------------------------------------------------------------------------- \n\n")
         }
-        dat1 <- dat1[,1:3]
-        # arrange ability estimates
-        abil <- data.frame( dat1, theta )
-        abil <- merge( freq.patt, abil[ c(1,4)], 1, 1, all=T )
-        abil <- abil[ order(abil[,3]), c( 3,1,2,4) ]
-        colnames(abil) <- c("person", "pattern", "meancorrect", "theta" )
-        if (method=="MLE"){
-            abil[abil$meancorrect==0, 4 ] <- -Inf
-            abil[abil$meancorrect==1, 4 ] <- Inf
-            }
-        # standard error of person parameter
-        abil$se.theta <- rasch.info.mle( dat=dat, theta=abil$theta,
-                    b=b * (I-1)/I)
-
-        # empirical discrimination
-        a.i <- emp.discr( theta, b, dat2, dat2.resp, dat1[,2] )
-        # calculate itemfit statistics
-        if (calc.fit){
-            fit <- rasch.itemfit( theta0=abil$theta, b=b, dat )
-            } else {fit <- NULL }
-
-        # standard error for item parameter
-        se.b <- .se.item.rasch( theta=theta, b=b, dat.resp=dat2.resp, freq=dat1[,2], constraints=constraints)
-
-        # Data frame for "item side"
-        I <- length(b)
-        # item parameter constraints and correction formula
-        UJJ <- 0
-#        if ( ! is.null(constraints)){ UJJ <- nrow(constraints) }
-        # item summary
-        dfr <- data.frame(
-                    "N"=colSums( dat2.resp  * dat1[,2] ),
-                    "p"=colMeans( dat, na.rm=T ),
-                    "itemdiff"=b,
-                    "itemdiff.correction"=b * (I-UJJ-1)/(I-UJJ),
-                    "se"=se.b,
-                    "discr"=a.i   )
-     # include item fit statistics                              #
-        if (calc.fit){     dfr <- data.frame( dfr, fit )  }
-     rownames(dfr) <- colnames(dat)
-     # processed data
-     data.proc <- list( "data"=dat2, "data.resp"=dat2.resp,
-            "theta"=theta )
-     # result
-     res <- list( "item"=dfr, "person"=abil, "method"=method,
-                    "dat"=dat, "deviance"=dev1,
-                    "data.proc"=data.proc,
-                    "dp"=dp, "constraints"=constraints,
-                    "method"=method )
-     class(res) <- "rasch.jml"
-     return( res )
-
-        }
-#-------------------------------------------------------------------------------------------------------------#
-
-#--------------------------------------------------------------------------------------------------------#
-# update item difficulty estimation (Rasch model)
-.update.b.rasch.jml2 <- function( b, theta,
-         freq.thetapattern,  freq.dat.resp.thetapattern    ,
-                constraints=NULL, conv=.0001,
-                suffB, progress=progress, bsteps=4){
-    #-------------------------------------------------------
-    # INPUT:
-    # b     ... initial item difficulties
-    # theta ... ability estimate
-    # freq  ... frequency of item response pattern (theta estimate)
-    # dat   ... data frame
-    # update item difficulties
-    b.change <- 1
-    iter <- 0
-    while( max( abs( b.change  ) ) > conv & ( iter < bsteps ) ){
-        p.ia <- stats::plogis( theta, matrix( b, nrow=length(theta), length(b), byrow=T ) )
-        deriv <- colSums( - freq.thetapattern * p.ia * ( 1- p.ia ) )
-        diff <- suffB + colSums( freq.dat.resp.thetapattern *  p.ia  )
-        b.change <-  diff / deriv
-        if (! is.null(constraints)){
-                b.change[ constraints[,1] ] <- 0
-                    }
-        if (progress){    cat("-"); utils::flush.console() }
-        b <- b - b.change
+        theta <- m1$theta
+        theta <- theta[ dat1$theta.index ]
+        # centering
+        theta <- rasch_jml_centerpersons(theta=theta, dat1=dat1, centerpersons=centerpersons)
+        # calculate Log-Likelihood and Deviance
+        p.ia <- (m1$p.ia)[ dat1$theta.index, ]
+        dev1 <- -2*sum( rowSums( ( d2d2r * log( p.ia ) + d2d2m * log( 1 - p.ia ) ) ) * dat1[,2]  )
+        # relative deviance change
+        dev1a <- - (dev1 - dev0)
+        dev.change <- abs( dev1 - dev0 ) / dev0 ;
+        dev0 <- dev1
+        # iteration index
         iter <- iter + 1
-                }
-    b
+        # display convergence
+        bconv <- max( abs(b - b0 ) )
+        if ( progress ){
+            cat( paste( "\n  Deviance", sirt_sign_space(), round( dev1, 5 ) ))
+            if (iter > 1){
+                cat( paste0( " | Deviance change", sirt_sign_space(), round( dev1a, 5 ) ) )
+            }
+            cat( paste0("\n  Max. parm. change", sirt_sign_space(), round( bconv, 6 ), "\n"  ) )
+            utils::flush.console()
+        }
     }
-#-----------------------------------------------------------------------------------------------------------#
+    #------------- end algorithm
+
+    if ( progress ){
+        if ( iter < jmliter ){
+            cat( paste( "Convergence reached in", iter, "JML Iterations \n" ) )
+        } else {
+            cat( paste( "Analysis terminated at", iter, "JML Iterations \n" ) )
+        }
+        cat("-----------------------------------------------------------------\n\n")
+    }
+    dat1 <- dat1[,1:3]
+    # arrange ability estimates
+    abil <- data.frame( dat1, theta )
+    abil <- merge( freq.patt, abil[ c(1,4)], 1, 1, all=T )
+    abil <- abil[ order(abil[,3]), c( 3,1,2,4) ]
+    colnames(abil) <- c("person", "pattern", "meancorrect", "theta" )
+    if (method=="MLE"){
+        abil[abil$meancorrect==0, 4 ] <- -Inf
+        abil[abil$meancorrect==1, 4 ] <- Inf
+    }
+
+    # standard error of person parameter
+    abil$se.theta <- rasch.info.mle( dat=dat, theta=abil$theta, b=b * (I-1)/I)
+
+    #- summary ability parameters
+    theta_summary <- rasch_jml_person_parameters_summary(x=abil[ is.finite(abil$theta), "theta"])
+
+    # empirical discrimination
+    a.i <- rasch_jml_emp_discrim( theta=theta, b=b, dat=dat2, dat.resp=dat2.resp, freq=dat1[,2] )
+
+    # calculate itemfit statistics
+    if (calc.fit){
+        fit <- rasch.itemfit( theta0=abil$theta, b=b, dat )
+    } else {
+        fit <- NULL
+    }
+
+
+    # standard error for item parameter
+    se.b <- .se.item.rasch( theta=theta, b=b, dat.resp=dat2.resp, freq=dat1[,2], constraints=constraints)
+
+    # Data frame for "item side"
+    I <- length(b)
+    # item parameter constraints and correction formula
+    UJJ <- 0
+    # item summary
+    dfr <- data.frame(  N=colSums(dat2.resp*dat1[,2]),
+                p=colMeans( dat, na.rm=TRUE ), itemdiff=b,
+                itemdiff.correction=b*(I-1)/I, se=se.b, discr=a.i )
+    if ( ! is.null(constraints)    ){
+        dfr$itemdiff.correction <- dfr$itemdiff
+    }
+
+
+    # include item fit statistics                              #
+    if (calc.fit){
+        dfr <- data.frame( dfr, fit )
+    }
+    rownames(dfr) <- colnames(dat)
+
+    # processed data
+    data.proc <- list( "data"=dat2, "data.resp"=dat2.resp, "theta"=theta )
+    s2 <- Sys.time()
+    time_diff <- s2-s1
+    #--- output
+    res <- list( item=dfr, person=abil, theta_summary=theta_summary,
+                    method=method,dat=dat, deviance=dev1,
+                    data.proc=data.proc, dp=dp, constraints=constraints, N=N, I=I,
+                    method=method, center=center, iter=iter,
+                    CALL=CALL, s1=s1, s2=s2, time_diff=time_diff )
+    class(res) <- "rasch.jml"
+    return(res)
+}
+
+# cat("fit") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
 #---------------------------------------------------------------------------------
 # Functions for calculating standard errors in the Rasch Model                   #
@@ -356,11 +338,15 @@ mle.rasch <- function( dat, dat.resp=1-is.na(dat), b, theta, conv=.001,
     p.ia <- stats::plogis( outer( theta, b, "-" ) )
     colSums( - freq * p.ia * ( 1- p.ia ) )
     }
-# calculate P_i ( theta)
-.prob.rasch <- function( theta, b ){
-#    plogis( outer( theta, b, "-" ) )
-    stats::plogis( theta, matrix( b, nrow=length(theta), length(b), byrow=T ) )
-    }
+
+#---- calculate P_i ( theta)
+.prob.rasch <- function( theta, b )
+{
+    bM <- matrix( b, nrow=length(theta), length(b), byrow=TRUE )
+    res <- stats::plogis( theta - bM )
+    return(res)
+}
+
 # calculate P_i(theta) for 3PL model
 .prob.3pl <- function( theta, b, a, c){
     l1  <- rep( 1, length(theta) )
@@ -465,50 +451,8 @@ item.discrim <- function( dat, score ){
     }
 #------------------------------------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------------
-# Function for calculating empirical discrimination
-# slope estimation (WINSTEPS manual p. 300)
-emp.discr <- function( theta, b, dat, dat.resp=1 - is.na(dat.resp), freq ){
-        pni <- .prob.rasch( theta, b )
-        tbdiff <- ( theta - outer( rep( 1, length(theta) ), b ) )
-        t1 <- colSums( ( dat - pni ) * tbdiff * dat.resp * freq )
-        t2 <- colSums( pni * ( 1 - pni ) * tbdiff^2 * dat.resp * freq )
-        1 + t1/t2
-        }
-#-------------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------------------------#
-# Itemfit Rasch model                                                                       #
-##NS export(rasch.itemfit)
-rasch.itemfit <- function( theta0, b, dat ){
-    dat9 <- dat
-    dat9[ is.na(dat)] <- 9
-    ind <- is.finite(theta0)
-    dat2 <- dat9[ ind, ]
-    dat2.resp <- 1 * ( dat2 !=9 )
-    theta0 <- theta0[ ind ]
-    p <- .prob.rasch( theta0, b )
-    z2 <- dat2.resp * ((dat2 - p)/sqrt(p * (1 - p)))^2
-    v <- sqrt(p * (1 - p))^2
-    infit <- colSums( z2 * v * dat2.resp ) / colSums( v * dat2.resp )
-    outfit <- colSums(z2  * dat2.resp) / colSums( dat2.resp )
-    data.frame(infit, outfit )
-    }
-#--------------------------------------------------------------------------------------------#
 
-#*******************************************************
-# Summary for rasch.jml object                         *
-##NS S3method(summary, rasch.jml)
-summary.rasch.jml <- function( object, ... ){
-    cat("---------------------------------------------------------------------------------------------------------- \n")
-    cat("Joint Maximum Likelihood Estimation \n")
-    cat("Rasch Model \n")
-    cat("---------------------------------------------------------------------------------------------------------- \n")
-    cat( "Deviance=", round( object$deviance, 2 ), "\n \n" )
-    cat("Item Parameter \n\n")
-    print( round( object$item, 3 ))
-                }
-#*******************************************************
 
 ##########################################################################################
 rasch.jml.jackknife1 <- function( jmlobj  ){
@@ -520,7 +464,7 @@ rasch.jml.jackknife1 <- function( jmlobj  ){
     dat <- jmlobj$dat
     Nobs <- nrow( dat )
     I <- ncol(dat)
-    if ( is.null( jackunits)){ jackunits <- 1:I }
+    if ( is.null(jackunits) ){ jackunits <- 1:I }
     UJ <- max( jackunits)
     # define jackknife units
     if ( length(jackunits) > 1){
